unit base;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils,Process

{$IFDEF WIN64}
  ,winsock
{$ENDIF}
  ;

Const
  msg_INOF   = 'INOF';    msg_INON   = 'INON';   // Internet On/Off
  msg_IROF   = 'IROF';    msg_IRON   = 'IRON';   // Intranet On/Off
  msg_UFOF   = 'UFOF';    msg_UFON   = 'UFON';   // URL-Filter On/Off
  msg_DROF   = 'DROF';    msg_DRON   = 'DRON';   // Raum-Drucker On/Off

  msg_GRST   = 'GRST';   // Get Room Default Status im akt. Raum
  msg_SRST   = 'SRST';   // Set Room Default
  msg_GROO   = 'GROO';   // Get alle PCs in akt. Raum: IP,MAC,PC-Name
  msg_GDRU   = 'GDRU';   // Get alle Drucker des Raums
  msg_GIPS   = 'GIPS';   // Get alle IPs im akt. Raum
  msg_AUTH   = 'AUTH';   // Credentials überprüfen: OK|DENY
  msg_SWOL   = 'SWOL';   // Wake On Lan für akt. Raum

  msg_GDST   = 'GDST';   // Get Drucker Status - Erster Drucker des Raums: ACCEPT|REJECT
  msg_GLIN   = 'GLIN';   // Get Logins der User im Raum über smbstatus: PC1,Login PC2,Login, ...

  msg_AARA   = 'AARA';   // Austeilen aktueller Raum
  msg_EARA   = 'EARA';   // Einsammeln und Löschen
  msg_EARC   = 'EARC';   // Einsammeln nur Copy

  msg_Nachricht = 'NACHRICHT:';
  msg_Befehl    = 'BEFEHL:';
  msg_poweroff  = 'POWEROFF';
  msg_reboot    = 'REBOOT';
  msg_logout    = 'LOGOUT';
  msg_sperren   = 'SPERREN';
  msg_sperrenU  = 'SPERRENU';     // mit Uhr
  msg_freigeben = 'FREIGEBEN';

  DefSKPort  = 9731;
  DefMDPort  = 9731;
  BT_max = 7;
  SleepTime = 50;

  ret = #13;
  WhiteSpace = [' ',#9,#10,#13];
  Literals = ['"',''''];

Var
  myBenutzer : String;

procedure Split(Delimiter: Char; Str: string; ListOfStrings: TStrings) ;
procedure WSplit(Str: string; ListOfStrings: TStrings);
Function GetBenutzer : String;
function GetComputername : String;
Function ipauslesen:string;
Function ZerlegeIP(IP:string; VAR b1,b2,b3,b4 : integer):Boolean;
function vtr(t:String):String;

implementation

function GetComputername : String;
Var
  hostname : TProcess;
  Ausgabe  : TStringList;
Begin
 {$IFDEF WIN64}
   Result := Lowercase(GetEnvironmentVariable('COMPUTERNAME'));
 {$ENDIF}
 {$IFDEF LINUX}
   hostname := TProcess.Create(nil);
   Ausgabe := TStringList.create;
   hostname.CommandLine := '/bin/hostname';
   hostname.Options := hostname.Options+[poWaitOnExit,poUsePipes] ;
   hostname.execute;
   Ausgabe.LoadFromStream(hostname.output);
   if Ausgabe.count>0 then Result := Lowercase(trim(Ausgabe[0]))
                      else Result :='';
   Ausgabe.free;
   hostname.free;
 {$ENDIF}
end;

function ipauslesen:string;
{$IFDEF WIN64}
var
  rSockVer   : WordRec;
  aWSAData   : TWSAData;
  szHostName : array[0..255] of Char;
  pHE        : PHostEnt;
  sIP        : String;
begin
  // WinSock Version 1.1 initialisieren
  rSockVer.Hi := 1;
  rSockVer.Lo := 1;
  WSAStartup(Word(rSockVer), aWSAData );
  try
    FillChar(szHostName, SizeOf(szHostName), #0);
    GetHostName(szHostName, SizeOf(szHostName));
    pHE := GetHostByName(szHostName);
    if Assigned(pHE)
      then with pHE^ do
        sIP := Format('%d.%d.%d.%d',[Byte(h_addr^[0]), Byte(h_addr^[1]),Byte(h_addr^[2]), Byte(h_addr^[3])]);
  finally
    WSACleanup;
  end;
  result:= sIP;
end;
{$ENDIF}
{$IFDEF Linux}
Var
  ifconfig : TProcess;
  Ausgabe  : TStringList;
  ipListe  : TStringList;
  n,p1,p2  : integer;
begin
  ifconfig := TProcess.Create(nil);
  Ausgabe  := TStringList.create;
  ipListe  := TStringList.create;
  ifconfig.CommandLine := '/sbin/ifconfig';
  ifconfig.Options := ifconfig.Options+[poWaitOnExit,poUsePipes] ;
  ifconfig.execute;
    Ausgabe.LoadFromStream(ifconfig.output);
    result:='';
    if (Ausgabe.Count > 0) then
      Begin
        for n:= 0 to Ausgabe.count-1 do
          Begin
            p1 := Pos('inet Adresse',Ausgabe[n]);
            p2 := Pos('Bcast:',Ausgabe[n]);
            if (p1 > 0) and (p2 > 0) and (p2>p1+21)then
              Begin
                ipListe.append(Copy(Ausgabe[n],p1+13,p2-p1-15));
                break;
              end;
          end;
        result:=ipListe.text;
      end
    else
      Begin
        result :='';
      end;
  ifconfig.free;
  Ausgabe.free;
  ipListe.free;
end;
{$ENDIF}

procedure Split(Delimiter: Char; Str: string; ListOfStrings: TStrings) ;
begin
   ListOfStrings.Clear;
   ListOfStrings.Delimiter     := Delimiter;
   ListOfStrings.DelimitedText := Str;
end;

procedure WSplit(Str: string; ListOfStrings: TStrings);
begin
   ListOfStrings.Clear;
   ListOfStrings.StrictDelimiter:=false;
   ListOfStrings.Delimiter     := ' ';
   ListOfStrings.DelimitedText := Str;
end;




Function ZerlegeIP(IP:string; VAR b1,b2,b3,b4 : integer):Boolean;
Const
  zeichen = '0123456789.';
  bmax = 255;
Var
  n,L,pp      : integer;
  p1,p2,p3    : integer;
  s           : String;
Begin
 s  := Trim(IP);
 result := false;
 L  := length(s);
 pp := 0;
 for n:= 1 to L do
   Begin
     if pos(s[n],zeichen)=0 then exit;
     if s[n]='.' then inc(PP);
   end;
 if pp <> 3 then exit;
 p1 := pos('.',s);
 b1 := StrToIntDef(Copy(S,1,p1-1),bmax+1);
 s  := Copy(S,p1+1,L);
 p2 := pos('.',s);
 b2 := StrToIntDef(Copy(S,1,p2-1),bmax+1);
 s  := Copy(S,p2+1,L);
 p3 := pos('.',s);
 b3 := StrToIntDef(Copy(S,1,p3-1),bmax+1);
 b4 := StrToIntDef(Copy(S,p3+1,L),bmax+1);
 if (b1 <= bmax) and (b2 <= bmax)  and (b3 <= bmax) and (b4 <= bmax) then result := True;
end;


Function GetBenutzer : String;
Begin
 {$IFDEF WIN64}
  Result    := GetEnvironmentVariable(String('USERNAME'));
{$ENDIF}
{$IFDEF Linux}
  Result    := GetEnvironmentVariable('USER');
{$ENDIF}
end;

function vtr(t:String):String;
Var
  n,l : integer;
  r,s   : String;
Begin
 r := '';
 s := t;
 l := length(t);
 if (l mod 2) = 1 then
   Begin
     r := t[l];
     l := l-1;
     s := copy(s,1,l);
   end;
 l := l div 2;
 for n := 1 to l do
   Begin
     r := s[n*2-1]+s[n*2]+r
   end;
 result := r;
end;


end.

